package SteamProperties "simple steam table properties"

  import Modelica.SIunits;

function fsteam "linear approximation to steam table at 60 bar pressure and 2800 kJ/kg spec. enthalpy"
  input SIunits.Pressure p;
  input SIunits.SpecificEnthalpy h;
  output SIunits.Density rho;
protected
  parameter SIunits.Pressure p0=60.0e5;
  parameter SIunits.SpecificEnthalpy h0=2.8e6;
  parameter SIunits.Density rho0=30.29526;
  parameter Real ap=5.115157e-6;
  parameter Real ah=-3.345309e-5 "linearization parameters of steamtable ";
protected
  Real delp;
  Real delh;
  annotation (
    derivative=fsteam_der,
    Icon(Text(
        extent=[-78, 62; 76, 18],
        string="Property function",
        style(color=0)), Text(
        extent=[-64, 20; 72, -14],
        string="rho = f(p,h)",
        style(color=0))),
    Coordsys(
      extent=[-100, -100; 100, 100],
      grid=[2, 2],
      component=[20, 20]),
    Window(
      x=0.33,
      y=0.3,
      width=0.32,
      height=0.48),
Documentation(info="<HTML>
	      <h4>function description</h4>
	      <p>This is a linear approximation to the IF97-version of the steam tables at the point
	      p = 60 bars, h = 2.8e3kJ/kg.
</HTML>
"));
algorithm
  delp := p - p0;
  delh := h - h0;
  rho := rho0 + ap*delp + ah*delh;
end fsteam;

end SteamProperties;
